@@ -3,6 +3,7 @@ XPath selectors based on lxml
 """
 
 from lxml import etree
+import six
 
 from scrapy.utils.misc import extract_regex
 from scrapy.utils.trackref import object_ref
@@ -15,11 +16,17 @@ from .csstranslator import ScrapyHTMLTranslator, ScrapyGenericTranslator
 
 __all__ = ['Selector', 'SelectorList']
 
+
+class SafeXMLParser(etree.XMLParser):
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('resolve_entities', False)
+        super(SafeXMLParser, self).__init__(*args, **kwargs)
+
 _ctgroup = {
     'html': {'_parser': etree.HTMLParser,
              '_csstranslator': ScrapyHTMLTranslator(),
              '_tostring_method': 'html'},
-    'xml': {'_parser': etree.XMLParser,
+    'xml': {'_parser': SafeXMLParser,
             '_csstranslator': ScrapyGenericTranslator(),
             '_tostring_method': 'xml'},
 }
@@ -57,6 +64,7 @@ class Selector(object_ref):
         # set:trailing
         "set": "http://exslt.org/sets"
     }
+    _lxml_smart_strings = False
 
     def __init__(self, response=None, text=None, type=None, namespaces=None,
                  _root=None, _expr=None):
@@ -85,9 +93,11 @@ class Selector(object_ref):
             return SelectorList([])
 
         try:
-            result = xpathev(query, namespaces=self.namespaces)
+            result = xpathev(query, namespaces=self.namespaces,
+                             smart_strings=self._lxml_smart_strings)
         except etree.XPathError:
-            raise ValueError("Invalid XPath: %s" % query)
+            msg = u"Invalid XPath: %s" % query
+            raise ValueError(msg if six.PY3 else msg.encode("unicode_escape"))
 
         if type(result) is not list:
             result = [result]
