@@ -1,7 +1,7 @@
 import re
-import inspect
 import warnings
 import weakref
+import six
 from twisted.trial import unittest
 from scrapy.exceptions import ScrapyDeprecationWarning
 from scrapy.http import TextResponse, HtmlResponse, XmlResponse
@@ -189,17 +189,19 @@ class SelectorTestCase(unittest.TestCase):
         self.assertEqual(xs.xpath('.').extract(), [u'<root>lala</root>'])
 
     def test_invalid_xpath(self):
+        "Test invalid xpath raises ValueError with the invalid xpath"
         response = XmlResponse(url="http://example.com", body="<html></html>")
         x = self.sscls(response)
         xpath = "//test[@foo='bar]"
-        try:
-            x.xpath(xpath)
-        except ValueError as e:
-            assert xpath in str(e), "Exception message does not contain invalid xpath"
-        except Exception:
-            raise AssertionError("A invalid XPath does not raise ValueError")
-        else:
-            raise AssertionError("A invalid XPath does not raise an exception")
+        self.assertRaisesRegexp(ValueError, re.escape(xpath), x.xpath, xpath)
+
+    def test_invalid_xpath_unicode(self):
+        "Test *Unicode* invalid xpath raises ValueError with the invalid xpath"
+        response = XmlResponse(url="http://example.com", body="<html></html>")
+        x = self.sscls(response)
+        xpath = u"//test[@foo='\u0431ar]"
+        encoded = xpath if six.PY3 else xpath.encode('unicode_escape')
+        self.assertRaisesRegexp(ValueError, re.escape(encoded), x.xpath, xpath)
 
     def test_http_header_encoding_precedence(self):
         # u'\xa3'     = pound symbol in unicode
@@ -297,6 +299,51 @@ class SelectorTestCase(unittest.TestCase):
         sel.remove_namespaces()
         self.assertEqual(len(sel.xpath("//link/@type")), 2)
 
+    def test_smart_strings(self):
+        """Lxml smart strings return values"""
+
+        class SmartStringsSelector(Selector):
+            _lxml_smart_strings = True
+
+        body = """<body>
+                    <div class='one'>
+                      <ul>
+                        <li>one</li><li>two</li>
+                      </ul>
+                    </div>
+                    <div class='two'>
+                      <ul>
+                        <li>four</li><li>five</li><li>six</li>
+                      </ul>
+                    </div>
+                  </body>"""
+
+        response = HtmlResponse(url="http://example.com", body=body)
+
+        # .getparent() is available for text nodes and attributes
+        # only when smart_strings are on
+        x = self.sscls(response)
+        li_text = x.xpath('//li/text()')
+        self.assertFalse(any(map(lambda e: hasattr(e._root, 'getparent'), li_text)))
+        div_class = x.xpath('//div/@class')
+        self.assertFalse(any(map(lambda e: hasattr(e._root, 'getparent'), div_class)))
+
+        x = SmartStringsSelector(response)
+        li_text = x.xpath('//li/text()')
+        self.assertTrue(all(map(lambda e: hasattr(e._root, 'getparent'), li_text)))
+        div_class = x.xpath('//div/@class')
+        self.assertTrue(all(map(lambda e: hasattr(e._root, 'getparent'), div_class)))
+
+    def test_xml_entity_expansion(self):
+        malicious_xml = '<?xml version="1.0" encoding="ISO-8859-1"?>'\
+            '<!DOCTYPE foo [ <!ELEMENT foo ANY > <!ENTITY xxe SYSTEM '\
+            '"file:///etc/passwd" >]><foo>&xxe;</foo>'
+
+        response = XmlResponse('http://example.com', body=malicious_xml)
+        sel = self.sscls(response=response)
+
+        self.assertEqual(sel.extract(), '<foo>&xxe;</foo>')
+
 
 class DeprecatedXpathSelectorTest(unittest.TestCase):
 
@@ -310,7 +357,7 @@ class DeprecatedXpathSelectorTest(unittest.TestCase):
 
             # subclassing must issue a warning
             self.assertEqual(len(w), 1, str(cls))
-            self.assertIn('scrapy.selector.Selector', str(w[0].message))
+            self.assertIn('scrapy.Selector', str(w[0].message))
 
             # subclass instance doesn't issue a warning
             usel = UserClass(text=self.text)
@@ -319,7 +366,7 @@ class DeprecatedXpathSelectorTest(unittest.TestCase):
             # class instance must issue a warning
             sel = cls(text=self.text)
             self.assertEqual(len(w), 2, str((cls, [x.message for x in w])))
-            self.assertIn('scrapy.selector.Selector', str(w[1].message))
+            self.assertIn('scrapy.Selector', str(w[1].message))
 
             # subclass and instance checks
             self.assertTrue(issubclass(cls, Selector))
@@ -334,7 +381,7 @@ class DeprecatedXpathSelectorTest(unittest.TestCase):
 
             # subclassing must issue a warning
             self.assertEqual(len(w), 1, str(cls))
-            self.assertIn('scrapy.selector.Selector', str(w[0].message))
+            self.assertIn('scrapy.Selector', str(w[0].message))
 
             # subclass instance doesn't issue a warning
             usel = UserClass(text=self.text)
@@ -343,7 +390,7 @@ class DeprecatedXpathSelectorTest(unittest.TestCase):
             # class instance must issue a warning
             sel = cls(text=self.text)
             self.assertEqual(len(w), 2, str((cls, [x.message for x in w])))
-            self.assertIn('scrapy.selector.Selector', str(w[1].message))
+            self.assertIn('scrapy.Selector', str(w[1].message))
 
             # subclass and instance checks
             self.assertTrue(issubclass(cls, Selector))
@@ -361,7 +408,7 @@ class DeprecatedXpathSelectorTest(unittest.TestCase):
 
             # subclassing must issue a warning
             self.assertEqual(len(w), 1, str(cls))
-            self.assertIn('scrapy.selector.Selector', str(w[0].message))
+            self.assertIn('scrapy.Selector', str(w[0].message))
 
             # subclass instance doesn't issue a warning
             usel = UserClass(text=self.text)
@@ -370,7 +417,7 @@ class DeprecatedXpathSelectorTest(unittest.TestCase):
             # class instance must issue a warning
             sel = cls(text=self.text)
             self.assertEqual(len(w), 2, str((cls, [x.message for x in w])))
-            self.assertIn('scrapy.selector.Selector', str(w[1].message))
+            self.assertIn('scrapy.Selector', str(w[1].message))
 
             # subclass and instance checks
             self.assertTrue(issubclass(cls, Selector))
